@@ -2,17 +2,13 @@ from . import (
     misc,
     parameter,
     index,
-    density,
     basis,
     sampler,
     chaos,
-    likelihood,
-    mcmc_sampling,
-    loggers
 )
 
 name = "pythia"
-__version__ = "1.2.0"
+__version__ = "3.0.1"
 __author__ = "Nando Farchmin"
 __credits__ = ["Physikalisch-Technische Bundesanstalt"]
 __maintainer__ = "Nando Farchmin"
